@@ -1,5 +1,5 @@
 cr.forward <-
-function(x,y) {
+function(x,y,weight) {
     yname <- as.character(substitute(y))
     if (!is.factor(y)) 
         y <- factor(y, exclude = NA)
@@ -10,13 +10,13 @@ function(x,y) {
 	if (length(names)==0) names<-paste("V",1:dim(x)[2],sep="")
     expand<-list()
     for (k in 1:kint) {    
-       expand[[k]]<-cbind(y[is.element(y,k:(kint+1))],x[is.element(y,k:(kint+1)),])
+       expand[[k]]<-cbind(y[is.element(y,k:(kint+1))],weight[is.element(y,k:(kint+1))],x[is.element(y,k:(kint+1)),])
        expand[[k]][,1]<-ifelse(expand[[k]][,1]==k,1,0)
        cp<-matrix(rep(0,dim(expand[[k]])[1]*kint),ncol=kint)
        cp[,k]<-1
        dimnames(cp)[[2]]<-paste("cp",1:kint,sep="")
        expand[[k]]<-cbind(expand[[k]],cp)
-	   dimnames(expand[[k]])[[2]]<-c("y",names,paste("cp",1:kint,sep=""))
+	   dimnames(expand[[k]])[[2]]<-c("y","weight",names,paste("cp",1:kint,sep=""))
     } 
 	newx<-expand[[1]]
 	for (k in 2:kint)  newx<-rbind(newx,expand[[k]])
